@@ -42,6 +42,10 @@ private slots:
 
     void on_browsertw_clicked();
 
+    void on_actionContattami_triggered();
+
+    void on_actionYoutube_triggered();
+
 private:
     Ui::MainWindow *ui;
 };
